==> oplist_v1.8.526.tgz: oplist/doc/merge-oracle-base-entries-oplist.sql <==
-- wir fuegen die Basisdaten ein; sofern ein Datensatz bereits
-- existiert wirft dieses Skript einen Fehler, das ist aber ganz
-- normal
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (1, 'offen', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (2, 'in Bearbeitung', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (3, 'erledigt', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (4, 'abgeschlossen', 1);
/
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (4, 'unbekannt', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (10, 'Mechanik', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (11, 'AT/Steuerung', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (12, 'IT', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (13, 'ISD', 1);
/
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (4, 'unbekannt', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (10, 'Connector-SST', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (11, 'MFR', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (12, 'Infosystem', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (13, 'CI_LOG', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (14, 'Pick-By-Light', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (15, 'Visualisierung', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (16, 'Funk', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (17, 'Simulation', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (18, 'OP-List', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (19, 'Datenbank', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (20, 'Hardware', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (21, 'SAP', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (22, 'Malfunction');
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (23, 'SyncSevice', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (24, 'javautil', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (25, 'UtilitiesRuntime', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (26, 'Tomcat', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (27, 'DatabaseUtils', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (28, 'LogReader', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (29, 'ReorganisationService', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (30, 'MobileDeviceService', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (31, 'Trade', 1);
/
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (1, 'Administrator', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (2, 'Kunde', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (3, 'IBN', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (4, 'PL/ATSYS/ITSYS', 1);
/
Insert into OPLIST_USERS
   (OPUID, OPGID, OPUUSERNAME, OPULNAME, OPUFNAME, OPUPASSWORD, OPUACTIVE, OPUDATE)
 Values
   (0, 3, 'nicht zugewiesen', 'unknown', 'unknown', 'KMndc4EVsjgTqGYvIWYj', 0, TO_DATE('11/17/2011 21:28:38', 'MM/DD/YYYY HH24:MI:SS'));
Insert into OPLIST_USERS
   (OPUID, OPGID, OPUUSERNAME, OPULNAME, OPUFNAME, OPUEMAIL, OPUPASSWORD, OPUACTIVE, OPUDATE)
 Values
   (1, 1, 'admin', 'Administrator', 'Administratorvorname', 'yourname@yourdomain.com', 'f51a239f51148ce4cd5b4a6df654dbc6', 1, TO_DATE('11/17/2011 21:28:38', 'MM/DD/YYYY HH24:MI:SS'));
/
exit

==> oplist_v16.10.1076.tgz: oplist/doc/merge-oracle-base-entries-oplist.sql <==
-- wir fuegen die Basisdaten ein; sofern ein Datensatz bereits
-- existiert wirft dieses Skript einen Fehler, das ist aber ganz
-- normal
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (1, 'offen', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (2, 'in Bearbeitung', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (3, 'erledigt', 1);
Insert into OPLIST_STAT
   (OPSID, OPSTEXT, ACTIVE)
 Values
   (4, 'abgeschlossen', 1);
/
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (4, 'unbekannt', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (10, 'Mechanik', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (11, 'AT/Steuerung', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (12, 'IT', 1);
Insert into OPLIST_AREA
   (OPAID, OPATEXT, ACTIVE)
 Values
   (13, 'ISD', 1);
/
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (4, 'unbekannt', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (10, 'Connector-SST', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (11, 'MFR', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (12, 'Infosystem', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (13, 'CI_LOG', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (14, 'Pick-By-Light', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (15, 'Visualisierung', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (16, 'Funk', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (17, 'Simulation', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (18, 'OP-List', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (19, 'Datenbank', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (20, 'Hardware', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (21, 'SAP', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (22, 'Malfunction');
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (23, 'SyncSevice', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (24, 'javautil', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (25, 'UtilitiesRuntime', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (26, 'Tomcat', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (27, 'DatabaseUtils', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (28, 'LogReader', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (29, 'ReorganisationService', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (30, 'MobileDeviceService', 1);
Insert into OPLIST_PRODUCT
   (OPPID, OPPTEXT, ACTIVE)
 Values
   (31, 'Trade', 1);
/
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (1, 'Administrator', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (2, 'Kunde', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (3, 'IBN', 1);
Insert into OPLIST_GROUP
   (OPGID, OPGTEXT, ACTIVE)
 Values
   (4, 'PL/ATSYS/ITSYS', 1);
/
Insert into OPLIST_USERS
   (OPUID, OPGID, OPUUSERNAME, OPULNAME, OPUFNAME, OPUPASSWORD, OPUACTIVE, OPUDATE)
 Values
   (0, 3, 'nicht zugewiesen', 'unknown', 'unknown', 'KMndc4EVsjgTqGYvIWYj', 0, sysdate);
Insert into OPLIST_USERS
   (OPUID, OPGID, OPUUSERNAME, OPULNAME, OPUFNAME, OPUEMAIL, OPUPASSWORD, OPUACTIVE, OPUDATE)
 Values
   (1, 1, 'admin', 'Administrator', 'Administratorvorname', 'yourname@yourdomain.com', '21232f297a57a5a743894a0e4a801fc3', 1, sysdate);
/
exit
